{% load staticfiles %}
<html>
<head>
	<link rel="stylesheet" href="{% static "libs/bootstrap/dist/css/bootstrap.css" %}">
	<link rel="stylesheet" href="{% static "css/font-awesome.min.css" %}">
	<link rel="stylesheet" href="{% static "css/reports.css" %}">
</head>
<body ng-app="dashboard" ng-controller="ReportsController" ng-cloak>
	<page-overlay-pace></page-overlay-pace>
	{% include "reports_header.html" %}
  <hi-dash />
	<script src="{% static "libs/jquery.min.js"  %}"></script>
	<script src="{% static "libs/angular/angular.min.js"  %}"></script>
	<script src="{% static "libs/google-chart/ng-google-chart.min.js"  %}"></script>
	<script src="{% static "js/reports-hidash.js"  %}"></script>
	<script src="{% static "js/hidash-app.js"  %}"></script>
	<script src="{% static "libs/highcharts.min.js" %}"></script>
	<script src="{% static "libs/exporting.min.js" %}"></script>
	<script src="{% static "libs/pace.js"  %}"></script>
	<script src="{% static "libs/bootstrap/dist/js/bootstrap.js" %}"></script>
	<script src="{% static "libs/daterangepicker/moment.js" %}"></script>
	<script src="{% static "libs/ui-bootstrap-tpls-0.9.0.min.js" %}"></script>
</body>
</html>
