# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-10-12 07:39
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hidash', '0003_auto_20161005_0715'),
    ]

    operations = [
        migrations.AddField(
            model_name='scheduledreport',
            name='cron_expression',
            field=models.CharField(default=b'', max_length=100),
        ),
        migrations.AddField(
            model_name='scheduledreport',
            name='last_run_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='scheduledreport',
            name='next_run_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
